#
# spec file for package python-tqdm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         allpython python
%global flavor %{nil}
%if "%{flavor}" == "test"
%define test 1
%define pkg_suffix -test
%bcond_without test
%else
%define pkg_suffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-tqdm%{pkg_suffix}
Version:        4.67.1
Release:        2.1
Summary:        An extensible progress meter
License:        MIT AND MPL-2.0
URL:            https://github.com/tqdm/tqdm
Source:         https://files.pythonhosted.org/packages/source/t/tqdm/tqdm-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Enhances:       python-ipython
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module pytest-asyncio >= 0.24}
# Conditional required for SLE-15-SP4+
BuildRequires:  %{python_module numpy if (python-base without python36-base)}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tqdm = %{version}}
%if ! 0%{?_with_ringdisabled}
# Conditional required for SLE-15-SP4+
BuildRequires:  %{python_module pandas if (python-base without python36-base)}
%endif
# /SECTION
%endif
%python_subpackages

%description
tqdm lets you output a progress meter from within loops by wrapping
any iterable with "tqdm(iterable)".
tqdm's overhead is one order of magnitude less than python-progressbar
and does not require ncurses.

%package -n %{allpython}-tqdm-bash-completion
Summary:        Bash completion for python-tqdm
Requires:       bash-completion
Supplements:    %{python_module tqdm and bash-completion}

%description -n %{allpython}-tqdm-bash-completion
tqdm lets you output a progress meter from within loops by wrapping
any iterable with "tqdm(iterable)".
tqdm's overhead is one order of magnitude less than python-progressbar
and does not require ncurses.

This package provides the completion file for bash

%prep
%autosetup -p1 -n tqdm-%{version}
# ignore new asyncio mode warning from pytest-asyncio 0.17
sed -i 's/-W=error//' pyproject.toml
# remove bash shebang for completion script
sed -i '1 s/^#!.*/# bash completion for tqdm       -*- shell-script -*-/' tqdm/completion.sh
chmod a-x tqdm/completion.sh

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/tqdm
install -m 644 -D tqdm/completion.sh %{buildroot}%{_datadir}/bash-completion/completions/tqdm
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if !%{with test}
%post
%python_install_alternative tqdm

%postun
%python_uninstall_alternative tqdm
%endif

%if %{with test}
%check
# test_perf: flaky
# test_synchronisation: hangs
%pytest -k "not (tests_perf or tests_synchronisation)"
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst logo.png
%doc examples/
%license LICENCE
%{python_sitelib}/tqdm/
%{python_sitelib}/tqdm-%{version}.dist-info
%python_alternative %{_bindir}/tqdm

%files -n %{allpython}-tqdm-bash-completion
%license LICENCE
%{_datadir}/bash-completion/completions/tqdm
%endif

%changelog
* Thu Jan  9 2025 Daniel Garcia <daniel.garcia@suse.com>
- Remove nbval build dependency
* Mon Dec  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.67.1
  * fix gui (matplotlib syntax) (#1629)
  * misc test & framework updates
    + bump pytest-asyncio (#1630)
    + fix codecov rate limit
    + fix pybuild
    + sync dependencies
- Update BuildRequires from pyproject.toml
* Thu Nov 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.67.0
  * contrib.discord: replace disco-py with requests (#1536)
- from version 4.66.6
  * cli: zip-safe --manpath, --comppath (#1627)
  * misc framework updates (#1627)
    + fix pytest DeprecationWarning
    + fix snapcraft build
    + fix nbval DeprecationWarning
    + update & tidy workflows
    + bump pre-commit
    + docs: update URLs
- from version 4.66.5
  * support ncols auto-detection on FreeBSD (#1602 <- casperdcl/git-fame#98)
  * fix Python 3.13 CLI (#1594 <- #1585)
  * fix Python 3.13 tests (#1595 <- python/cpython#117536 (comment))
  * misc framework updates (#1602)
    + add official Python 3.12 support
    + bump deps (NiklasRosenstein/pydoc-markdown#329, tikitu/jsmin#44)
- Drop fix-issues-with-python3.13.patch, merged upstream
* Fri Aug  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix multiple issues with Python 3.13+
  * fix-issues-with-python3.13.patch
* Fri May 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Re-add conditionals to numpy/pandas, it is required.
* Tue May  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.66.4:
  * rich: fix completion (#1395 <- #1306)
  * cli: eval safety (CVE-2024-34062, bsc#1223880)
  * pandas: add DataFrame.progress_map (#1549)
  * notebook: fix HTML padding (#1506)
  * keras: fix resuming training when verbose>=2 (#1508)
  * fix format_num negative fractions missing leading zero (#1548)
  * fix Python 3.12 DeprecationWarning on import (#1519)
- Drop patch sprinkle-in-timezone.patch: Included upstream.
* Fri Nov 24 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch sprinkle-in-timezone.patch:
  * Add a timezone to the call fromtimestamp()
- Switch to autosetup macro.
- Remove conditionals from some BuildRequires.
* Wed Aug 30 2023 ecsos <ecsos@opensuse.org>
- %%{?sle15_python_module_pythons} must at beginning of spec to work.
* Thu Aug 10 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * switched to pyproject.toml build
- update to version 4.66.1:
  * fix utils.envwrap types (#1493 <- #1491, #1320 <- #966, #1319)
    e.g. cloudwatch & kubernetes workaround: export TQDM_POSITION=-1
  * drop mentions of unsupported Python versions
- changes from version 4.66.0:
  * environment variables to override defaults (TQDM_*) (#1491 <-
    [#1061], #950 <- #614, #1318, #619, #612, #370) e.g. in CI jobs,
    export TQDM_MININTERVAL=5 to avoid log spam add tests & docs for
    tqdm.utils.envwrap
  * fix & update CLI completion
  * fix & update API docs
  * minor code tidy: replace os.path => pathlib.Path
  * fix docs image hosting
  * release with CI bot account again (cli/cli#6680)
- changes from version 4.65.2:
  * exclude examples from distributed wheel (#1492)
- changes from version 4.65.1:
  * add Python 3.11 and drop Python 3.6 support (#1439, #1419, #502 <-
    [#720], #620)
  * misc code & docs tidy
  * fix & update CI workflows & tests
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 4.65.0:
  * add Python 3.11 and drop Python 3.6 support
  * misc code & docs tidy
  * fix & update CI workflows & tests
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Sep 10 2022 Arun Persaud <arun@gmx.de>
- update to 4.64.1:
  * support ipywidgets>=8 (#1366, #1361 <- #1310, #1359, #1360, #1364)
    + fix jupyter lab display
    + update notebook tests
* Sat Apr  9 2022 Arun Persaud <arun@gmx.de>
- update to version 4.64.0:
  * add contrib.slack (#1313)
- changes from version 4.63.2:
  * rich: expose options kwargs (#1282)
  * autonotebook: re-enable VSCode (#1309)
  * misc docs typos (#1301, #1299)
  * update dev dependencies (#1311)
* Sun Mar 27 2022 Arun Persaud <arun@gmx.de>
- update to version 4.63.1:
  * fix stderr/stdout missing flush() (#1248 <- #1177)
  * misc speed improvements/optimisations
* Sat Mar 12 2022 Arun Persaud <arun@gmx.de>
- update to version 4.63.0:
  * add __reversed__()
  * add efficient __contains__()
  * improve CLI startup time (replace pkg_resources => importlib)
  * tqdm.autonotebook warning & std fallback on missing ipywidgets
    (#1218 <- #1082, #1217)
  * warn on positional CLI arguments
  * misc build/test framework updates
    + enable py3.10 tests
    + add conda dependencies
    + update pre-commit hooks
    + fix pytest config (nbval, asyncio)
    + fix dependencies & tests
    + fix site deployment
* Sat Jan 22 2022 Ben Greiner <code@bnavigator.de>
- Ignore deprecation warnings from pytest-asycio for compatibility
  with 0.17
* Sat Nov 27 2021 Arun Persaud <arun@gmx.de>
- update to version 4.62.3:
  * fix minor typo (#1246)
  * minor example fix (#1246)
  * misc tidying & refactoring
  * misc build/dev framework updates
    + update dependencies
    + update linters
    + update docs deployment branches
  * misc test/ci updates
    + test forks
    + tidy OS & Python version tests
    + bump primary python version 3.7 => 3.8
    + beta py3.10 testing
    + fix py2.7 tests
    + better timeout handling
* Sun Aug 29 2021 Arun Persaud <arun@gmx.de>
- update to version 4.62.2:
  * fix notebook memory leak (#1216)
  * fix contrib.concurrent with generators (#1233 <- #1231)
* Thu Jul 22 2021 Arun Persaud <arun@gmx.de>
- update to version 4.61.2:
  * install colorama on Windows (#1139, #454)
  * add telegram support for leave=False (#1189)
  * support pandas==1.3.0 (#1199)
  * fix keras potential AttributeError (#1184 <- #1183)
  * fix py3.10 asyncio tests (#1176)
  * flush stdout/err before first render (#1177)
  * misc minor build & test framework updates (#1180)
* Sun Jul  4 2021 Arun Persaud <arun@gmx.de>
- update to version 4.61.1:
  * fix utils._screen_shape_linux() sometimes raising ValueError
    (#1174)
  * minor build/CI framework updates (#1175)
  * minor documentation updates
- changes from version 4.61.0 :
  * keras support for initial_epoch (#1150 <- #1138)
  * misc documentation updates
    + update & shorten URLs (#1163)
    + fix typos (#1162)
  * fix & update tests (#1163)
  * minor framework updates (#1163)
* Fri Apr 30 2021 Arun Persaud <arun@gmx.de>
- update to version 4.60.0:
  * add contrib.logging helpers for redirecting to tqdm.write() (#1155
    <- #786)
  * support delay in notebook (#1142)
  * fix contrib.tmap, tzip not using tqdm_class (#1148)
  * add notebook tests (#1143)
  * updates & misc minor fixes for documentation
* Sun Mar 28 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * remove pandas.patch, seems to be included upstreams
- update to version 4.59.0:
  * add tqdm.dask.TqdmCallback (#1079, #279 <- #278)
  * add asyncio.gather() (#1136)
  * add basic support for length_hint (#1068)
  * add & update tests
  * misc documentation updates (#1132)
    + update contributing guide
    + update URLs
    + bash completion: add missing --delay
  * misc code tidy
    + add [notebook] extra (#1135)
- changes from version 4.58.0:
  * add start delay in seconds (#836 <- #1069, #704)
  * add tests
  * misc code tidy (#1130)
  * misc documentation updates
- changes from version 4.57.0:
  * add line buffering for DummyTqdmFile (#960)
  * fix & update demo notebook (#1127)
  * fix py3 urllib examples (#1127)
  * suppress deprecated pandas warnings (#824, #1094)
  * misc framework updates
  * misc tests updates
  * misc code tidy
* Mon Feb 15 2021 Ben Greiner <code@bnavigator.de>
- Don't test pandas at all in Ring1 staging
* Sun Feb 14 2021 Ben Greiner <code@bnavigator.de>
- Update to 4.56.2
  * fix attribute errors when disabled (#1126)
  * add tests
- Changes in 4.56.1
  * fix repr() & format_dict when disabled (#1113 <- #624)
  * rename __repr__() => __str__()
  * minor documentation updates (#1113)
  * add & update tests
- Test numpy only for non python36 flavor (Numpy 1.20 in TW dropped
  Python 3.6, NEP 29), tests are automatically skipped if not
  installed.
- Remove unused and untested python3 flavor BuildRequirements in
  test build: ipython, ipykernel
- Enhance IPython
* Mon Feb  1 2021 Benjamin Greiner <code@bnavigator.de>
- Simplify the rich supplements in the bash completions package
* Wed Jan 13 2021 Markéta Machová <mmachova@suse.com>
- Update to 4.56.0
  * some tqdm.gui improvements
- Fix testsuite with pandas.patch
* Sun Jan 10 2021 andy great <andythe_great@pm.me>
- Update to version 4.55.2.
  * update tests
  * make pre-commit pytest quicker
  * switch pre-commit from make to python
  * update contributing guidelines
  * fix formatting
  * test dependencies
  * update .gitignore
  * fix (auto & manual) formatting
  * fix minor detected bugs
- Updates for 4.55.1.
  * fix (Rolling|Expanding).progress_apply() on pandas==1.2.0
  * minor documentation updates
- Updates for 4.55.0.
  * fix ASCII notebook export
  * fix notebook gui-mode extra spaces
  * better ETA for early iterations
  * better ETA for wildly varying iteration rates
  * update submodule inheritance
  * tqdm.gui
  * tqdm.notebook
  * tqdm.contrib.telegram
  * tqdm.contrib.discord
  * documentation updates
  * misc code optimisations
  * add tests
  * misc code linting/formatting
- Updates for 4.54.1.
  * drop py3.4 (no longer tested)
- Updates for 4.54.0.
  * get rid of get_new
- Updates for 4.53.0.
  * provide get_new() helper for mixed subclasses in nested mode
  * fix nested asyncio (#1074)
  * document async break hazard
  * add tests
  * drop py2.6/3.2/3.3 and distutils (no longer tested)
  * drop py2.6
  * drop distutils in favour of setuptools/setup.cfg
  * use setuptools_scm
  * fix & update tests
  * fix & upgrade snap build
  * update CONTRIBUTING docs
- Remove python-tqdm-remove-nose.patch, fixed.
* Tue Nov  3 2020 Benjamin Greiner <code@bnavigator.de>
- move bash completion into separate package to avoid conflicts
  with multiple python flavors gh#openSUSE/python-rpm-macros#66
* Fri Oct 23 2020 pgajdos@suse.com
- added patches
  https://github.com/tqdm/tqdm/pull/1052
  + python-tqdm-remove-nose.patch
* Sat Oct 10 2020 Arun Persaud <arun@gmx.de>
- update to version 4.50.2:
  * fixed platform.system() causing fork() warnings (#691)
  * fixed contrib.concurrent.process_map pickling error with
    threading.RLock (#920)
  * updated documentation & examples
  * updated CI framework
  * updated tests
  * misc code tidy
- changes from version 4.50.1 :
  * fix multiprocessing lock creation leak (#982, #936, #759)
    + fixes #617 which introduced this bug (v4.29.0, released
    2019-01-06, undiagnosed until now) where multiple threads could
    concurrently create and append process locks to a global list,
    then try to release them without first acquiring 👿
  * major test overhaul: fix, update, and speed up
  * misc CI framework updates
  * code linting
  * minor documentation tidy
- changes from version 4.50.0:
  * add bar colour option (#1040 <- #450)
    + for notebook as well as std/CLI
    + plain text as well as hex (e.g. 'green' or '#00ff00')
  * notebook improvements (#1032 <- #1031)
    + split bar description into separate widget
    + improve reset() (handle width and colour)
  * fix exceptions when file is closed (#1041, #1036 <- #1033)
  * add & update tests
  * minor documentation updates
  * move and configure issue/pr templates
* Sat Sep 19 2020 Arun Persaud <arun@gmx.de>
- update to version 4.49.0:
  * CLI: add --tee (#1014 <- #1013)
  * CLI: add --update and --update_to (#996 <- #975)
  * CLI: add --null (#996)
  * CLI: accept - instead of _ in options (e.g. --update-to)
  * make update() return True on display to ease efficient use of
    custom callbacks (#845)
  * fix py>=3 CLI --delim encoding error
  * fix py>=3.5 version detection in tqdm.auto (#1029 <- #1028)
  * fix final ETA when using initial (#1021 <- #689)
  * update documentation
    + add & update custom callback examples
    + improve help formatting of boolean CLI options
  * add & update tests
* Sat Aug 15 2020 Arun Persaud <arun@gmx.de>
- update to version 4.48.2:
  * fix notebook formatting
- changes from version 4.48.1:
  * fix ANSI escape codes breaking tqdm.write (#692, #777)
  * fix long-lived strongref (#1007,
    https://bugs.python.org/issue39093)
  * fix cli --version crash on missing git/refs/heads (#635)
  * fix contrib.tenumerate ignoring total (#1017)
  * fix potential deep => shallow kwargs copy issues
  * improve notebook display for unknown total (#1015)
  * make asyncio inherit from std rather than auto
  * make auto multi-inherit from autonotebook, asyncio on Python3.5+
  * misc documentation & examples updates
    + mention docker-compose requirements (#771)
  * misc linting & tidy
  * misc minor testing framework updates
* Sat Jul 18 2020 Arun Persaud <arun@gmx.de>
- update to version 4.48.0:
  * add tqdm.asyncio (#1004, #772, #91 <- #65)
    + supports async iterables (async for row in tqdm(iterable))
    + supports iterables
    + supports coroutine.send (tqdm(coroutine).send)
    + add as_completed wrapper (for f in tqdm.as_completed(fs))
  * reduce contrib.discord logging verbosity
  * fix potential pandas() modifying **kwargs bug
  * update documentation
    + add missing inline docstrings
    + update contributing notes
    + update readme
    + add to examples/ folder
    o async_coroutines
    o coroutine_pipe
    + standardise variable naming
  * add tests
    + add benchmark tests against popular alternative libraries
    + test new functionality
    + more thorough miniters test (#1003)
  * misc framework updates
    + tidy changelog helper
    + add helper bots
    o comment-bot /tag
    o post-release-bot
  - wiki updater
  - website updater
    o benchmark regressions
  - full/thorough test on schedule & release
  - quick test on PR
* Fri Jul  3 2020 Arun Persaud <arun@dhcp.lbl.gov>
- specfile:
  * fix location of bash completion
- update to version 4.47.0:
  * add contrib.discord (similar to contrib.telegram) (#976)
  * add contrib.bells to auto-enable all extras
  * add contrib.utils_worker for common slow tasks (e.g. web I/O)
    + fix lazy large memory usage & discard unsent messages
    (unprocessed tasks)
  * fix slow notebook imports (#955 <- #709)
  * fix gui TypeError on unknown len() (#971)
  * misc documentation/error message updates
    + more succinct ImportError on missing ipywidgets (#872)
    + fix broken/deprecated link (#981)
    + add inline usage for contrib.discord and contrib.telegram
  * misc framework updates
    + add official py3.8 support (#986)
    + fix snap builds
* Sun Jun 28 2020 Arun Persaud <arun@gmx.de>
- update to version 4.46.1:
  * fix missing sys.setcheckinterval in py3.9 (#978)
  * fix keras.TqdmCallback compatibility with tensorflow==2.2.0 (#979)
  * update documentation
    + correct contrib.concurrent correct max_workers (#977)
    + drop prominent mention of xrange (#965)
  * minor linting
* Sat May  9 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * add bash completion script
- update to version 4.46.0:
  * add contrib.telegram #949 <- #948
  * add bash tab completion and --comppath #946, #947 <- #858
  * fix exception safety in external_write_mode #940
  * add requests examples (#242)
  * update documentation
* Wed Apr  8 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 4.45.0:
  * propagate and close() on exceptions (#926 <- #548)
  * fix nested clear()
  * rework nested close() (#930 <- #924 <- #918, #677)
  * update all documentation & demos
  * add and update tests
  * dev framework: add pre-commit helper
  * fix _utils ImportError => DeprecationWarning
* Sat Feb 22 2020 Arun Persaud <arun@gmx.de>
- update to version 4.43.0:
  * fix notebook exceptions (#669 <- #650)
    + set_description() when disable=True
  * contrib.concurrent: avoid unnecessary len(iterable) (#893)
  * update documentation
    + clarify etymology (#895)
    + fix minor typo (#890)
    + update contributors and years
  * update tests
  * fix CI tests for PRs
* Sun Feb  9 2020 Arun Persaud <arun@gmx.de>
- update to version 4.42.1:
  * support pandas==1.0.0 (#780, #555)
  * minor metadata updates
  * minor CI test update
* Sun Jan 26 2020 Arun Persaud <arun@gmx.de>
- update to version 4.42.0:
  * notebook: update disable=None behaviour (#880)
  * tqdm.keras: support tensorflow.keras as well as keras (#885)
  * add contrib (#882)
    + tenumerate (#840 <- #480, #402)
    + tzip <= zip
    + tmap <= map
    + add concurrent module
    o thread_map <= concurrent.futures.ThreadPoolExecutor.map
    o process_map <= concurrent.futures.ProcessPoolExecutor.map
    + add itertools module (#225) stub
    o product
  * add & update tests
  * add & update documentation
    + README
    + examples/
  * update CI framework
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Remove unneeded python2 ipython-related testing dependencies.
  These packages are no longer available for python2 and the test
  suite will automatically skip them if they aren't available.
* Sun Jan  5 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 4.41.1:
  * fix batch_size=None
  * keras missing pop('size')
* Sun Dec 29 2019 Arun Persaud <arun@gmx.de>
- update to version 4.41.0:
  * trim on ncols overflow with ANSI handling (#850, #716 <- #690)
  * add notebook.reset() (#864)
  * add keras.TqdmCallback (#867 <- #835)
  * documentation updates
    + document newly added features (above)
    + notebook ncols percentage/pixels (#276)
  * test updates
    + test newly added features (above)
    + add CI for win and osx (#841)
    + py2 threading
* Fri Dec 13 2019 Arun Persaud <arun@gmx.de>
- update to version 4.40.2:
  * fix pandas unhashable func (#862 -> #863)
    + add tests
* Sat Dec  7 2019 Arun Persaud <arun@gmx.de>
- update to version 4.40.1:
  * test for floats for total
- changes from version 4.40.0:
  * officially support float for n and total (#802)
    + notebook: use FloatProgress <= IntProgress (#471, #456)
    + allow imprecision (n <= total + epsilon) (#849)
  * fix unicode bar format arguments (#803 -> #851)
  * add contrib submodule (#815)
  * add wrapattr, utils.CallbackIOWrapper, contrib.DummyTqdmFile (#84
  - > #844)
  * update tests
  * update documentation
  * tidy automatic snap deployments
  * minor doc update (#854)
* Sat Nov 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Don't use RPM internal/reserved name %%suffix (change to
  pkg_suffix).
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- update to version 4.39.0:
  * add pandas builtin operations check (#843 <- #697)
  * avoid unnecessary dedent (#837)
  * remove unneeded bar logic
  * misc code tidy
  * update documentation
    + document default argument overriding (#370)
    + add missing isatty() (#713)
    + update badges
    + add code of conduct
  * update framework
    + clean CI stages
    + update CI default py3.6 => py3.7
    + automate snap releases (#686 <- #685)
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- update to version 4.38.0:
  * support lock_args for e.g. non-blocking intermediate writes (#838
  - > #839)
    + use self.refresh() in more places
    + add and update performance tests
    + support args for TqdmDefaultWriteLock.acquire()
  * fix colorama on win (#678, #764)
  * framework updates
    + CI cleanup
    move to stages (check/test/deploy)
    auto deploy notes
    deploy only on parent repo
    separate docker deploy
    + update documentation sync/generation
  * update examples
  * update documentation
  * add and update tests
  * misc tidy and linting
- changes from version 4.37.0:
  * potential future pandas fix (#824)
  * better unicode widechar support (#803 -> #410, #805)
  * fix example/tqdm_wget unknown total (#826)
  * add stacklevel=2 to warnings (#821)
  * misc framework updates
    + snapcraft version fix
    + update issue/pr templates (#830)
    + update unit tests
  * misc documentation updates
    + update parallel (multiprocessing, ThreadPoolExecutor) example
    (#407)
    + add slides, video images
    + add CII Best Practices badge
    + add repology badge
    + update badge icons
* Sat Sep 21 2019 Arun Persaud <arun@gmx.de>
- update to version 4.36.1:
  * fix CLI entrypoint
- changes from version 4.36.0:
  * expose more custom format params
  * potential thread safety fix (#548)
  * update submodule architecture (#198 -> #800)
    + backward-compatibility
    + expose utils
    + rename main -> cli
    + add/fix tests
    + fix minor cached var optimisation
    + gui partial upgrade (#790)
    + notebook upgrade (#790)
    support {bar} in bar_format (#594)
    inherit methods including set_*(refresh) (#740 -> #741)
    + ready for contrib releases (#252)
  * support custom bar_format with unknown total
  * fix tqdm_notebook red block on explicit file=None (#791)
  * update notebook to fully support custom bar_format (#594, #649)
  * misc tidy
    + warnings
    + linting
    + update submodule contribution guide (#252)
    + parallel (py)make test
    + fix Zenodo metadata
  * update documentation
    + pandas, notebook, gui (#245)
    + indentation
    + update multiprocessing and multithreading examples (#796)
* Sun Aug 25 2019 Arun Persaud <arun@gmx.de>
- update to version 4.35.0:
  * add {bar} format specifier (#623 -> #799)
    [width][type]
  * add tests and documentation
  * update performance tests
- changes from version 4.34.0:
  * add leave=None convenience option for leave = position == 0
  * ensure nested completed bars respect leave=True (#230)
  * ensure nested bars are cleared before being moved up (#795)
  * support both and = syntax for CLI options (#761 -> #774)
  * misc documentation updates (#778, #782)
  * fix/update tests
  * update GitHub docker package deployment
* Fri Aug  9 2019 Todd R <toddrme2178@gmail.com>
- update to version 4.33.0:
  * fix pandas==0.25 API change
  * add contributor badges (sourcerer)
  * fix py26 travis CI
  * metadata fixes
    > .zenodo.json
    > CODEOWNERS
  * GitHub package registry docker deployment
  * minor linting
  * documentation updates
* Mon Jun 24 2019 Arun Persaud <arun@gmx.de>
- update to version 4.32.2:
  * fix 'Set changed size during iteration' (#481 -> #700, #754)
  * add tqdm.autonotebook check for $VSCODE_PID (#747 -> #751)
  * fix missing multiprocessing in Jython (#698)
  * make bool(tqdm(iter)) consistent with bool(iter) (#353 -> #694)
  * add and update unit tests
  * add and update documentation & framework
    + update notable contributors list
    + update usage docstrings (#714, #715)
    + add funding
    + add awesome-python badge
    + trove classifier update
    + update demo notebook badges
    + add JOSS DOI
    + add Zenodo metadata
    + move unnecessary root clutter
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.32.1
  * fix notebook with unknown total
- Update to 4.32.0
  * support unit_scale in notebook
  * support negative update (#432, #545)
  * add reset() function (#547, #545)
  * add [python setup.py] make run
- Fix jupyter dependencies.
* Sat Feb 16 2019 Arun Persaud <arun@gmx.de>
- update to version 4.31.1:
  * fix file.encoding==None caused by #598 (#673 -> #676)
    + add tests
  * tidy code, update authors and tests
    + add setup.py test to CI
- changes from version 4.31.0:
  * Write bytes to stdout/stderr in py2
    (https://bugs.python.org/issue21363, #589 -> #598)
    + Add write_bytes parameter for py2/3 default override
  * support custom bar characters vias ascii parameter (#223 -> #227)
    + implement, document and test custom bar spinners
  * support custom bar_format with unknown total (#282 -> #284)
  * fix TypeError when unit_scale and unknown total
  * document format_dict
  * expose elapsed_s, remaining_s to bar_format
  * add unit option to bar_format (#368)
  * auto README.rst generation framework
    + add notes in CONTRIBUTING.md
  * update tests
  * update documentation
  * misc code tidy
- changes from version 4.30.0:
  * avoid moving when leave=False
  * generalise nested bar tests
  * add display() helper function
  * add and expose format_dict (#562, #482, #494, #656)
    + allow arbitrary keyword arguments for format_meter
    + document format_dict overriding
    + add tests for overriding
    + related: #660 #172 #587
  * add and tidy developer documentation
  * fix py3 CLI pipe decoding error (#663)
  * framework overhaul (developing, testing, Travis CI updates)
  * tidy code and style (flake8)
  * setup.py refactor
    + setup.py make
  - add support for multi-line commands
  - tidy and efficiency
    + replace setup.py's built-in make -> py-make>=0.1.9 (#290)
    + add requirements-dev.txt and extras_require[dev]
  * add, update and tidy tests
  * include interactive Jupyter demonstration (#652 -> #659)
  * update documentation
    + add FAQ about py2 pipes (#359)
    + add badges
    + update examples
    + update authors
- changes from version 4.29.1:
  * fix classmethod lock bug (#617: #457 -> #658)
  * add unit test to prevent regression
- changes from version 4.29.0:
  * Avoid global multiprocessing locks (#611 -> #617)
  * Add support for infinite iterables (#651)
  * Fix missing attr pos when used in multi-threaded environment
    (#573)
  * Do not join TMonitor if it is the current thread (#613 -> #641)
  * Add OpenBSD NIX support (#638)
  * Unit tests, general documentation fixes and tidying (e.g. #642)
  * CI travis improvements
    + py37-dev -> py37 (#622)
    + fix py26
* Tue Feb 12 2019 Matej Cepl <mcepl@suse.com>
- Remove installed files after running the testsuite
* Sat Feb  9 2019 Matej Cepl <mcepl@suse.com>
- Switch to multibuild (with separate test) to avoid large
  dependencies on the main package.
* Mon Dec 31 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 4.28.1:
  * tqdm.main(): expose argv
  * cli: add working `--manpath`
  * fix CLI:--manpath not found issue
  * update .gitattributes
  * CLI unit tests
  * remove deprecated dist options
  * add missing auto submodule
  * PyPI fix
  * remove man page from distribution
  * cli:add `--man_path` option
* Wed Oct 17 2018 Arun Persaud <arun@gmx.de>
- update to version 4.27.0:
  * fix str.isnumeric #605
  * fix WeakSet KeyError #548, #553, #596 -> #607
  * stop tqdm_notebook description truncation #582 -> #599
  * include unit_scale for rate #608
  * add auto -> nowarning autonotebook
  * add better postfix numeric formatting #621
  * minor refactoring #609 -> #616
  * update documentation
  * add unit tests
  * fix py26 CI
* Sun Sep 16 2018 Arun Persaud <arun@gmx.de>
- update to version 4.26.0:
  * fix smoothing (#566 -> #601)
  * pandas updates
    + address the FutureWarning in pandas, drop pandas test in py34,
    add in py37 (#603)
    + support pandas axis='index' or 'columns' (#570)
  * minor documentation updates (#597, #600, #606)
    + developer notes
* Tue Aug 28 2018 tchvatal@suse.com
- Reenable testsuite
* Sat Aug 25 2018 arun@gmx.de
- specfile:
  * remove devel for noarch package
  * make %%files section more specific
- update to version 4.25.0:
  * stop monitor on shutdown (#571, #572)
  * fix find_packages() for submodules (#593)
    + properly add autonotebook (#586, 1cf3393)
  * ignore ANSI escape codes in the bar length calculation (#450, #591
  - > #592)
  * update documentation (#243)
* Tue Aug  7 2018 toddrme2178@gmail.com
- update to 4.24.0
  * autonotebook submodule for automatic selection of notebook/CLI bar (#443, #508)
    > update/add pandas() example documentation (#474)
  * NameError:IntProgress changed to a more helpful ImportError (#187, #451, #558)
  * support bool() cast when disable=True (#574)
  * fix format_sizeof hundreds rounding (#579 -> #581)
  * ensure URLs in documentation are secure (https)
* Sat Jul 14 2018 arun@gmx.de
- specfile:
  * removed patch support_pandas_23_groupby.patch (included upstream)
  * always run tests
- update to version 4.23.4:
  * Support pandas 0.23.0 core.groupby module layout (#555 -> #554)
  * Add python_requires to help pip (#557)
  * minor maintenance updates
    + CI updates: drop travis py33 due to tox (tox-dev/tox#648)
    + minor code tidy
* Thu May 17 2018 toddrme2178@gmail.com
- update to version 4.23.3
  * suppress warning
  * update .github things
- update to version 4.23.2
  * minor import syntax fix #496
  * re-fix nested overlaps #477
  * update documentation and examples
  * code tidy and abstraction
- update to version 4.23.1
  * fix AttributeErrors (#546)
    >   pos on initialisation (#323, #510 -> #544)
    >   fp on write() (#383)
  * fix py34 CI
  * update documentation
- update to version 4.23.0
  * Fix disable=True whereiterable has no len() and is not None (#539)
  * Add ncols to specify tqdm_notebook bar width (#276 -> #292)
  * allow custom pandas total (#364 -> #535)
  * Add progress_apply for pandas.(Series|DataFrame).(rolling|expanding) (#530 -> #537)
  * unit tests, pep8 tidy
  * postfix non-dict documentation note
- update to version 4.22.0
  * allow direct non-string assignment to postfix member (lists, dicts, etc) (#382 -> #534)
  * documentation updates
  * unit tests
- update to version 4.21.0
  * fix #532 write() with manual position
    >   more robust free position finding
  * add TqdmWarning base class
  * fix GUI __del__()
    >   add TqdmExperimentalWarning
  * add, tidy & fix unit tests
  * documentation
    >   wiki release notes
    >   update contributors
    >   fix 7zx example
- update to version 4.20.0
  * pandas wrapper: remove *args and add better total handling (#244, #299, #322, #366 -> #524)
  * document windows unicode know issues (#454)
  * suppress RuntimeError: Set changed size during iteration -> TqdmSynchronisationWarning
- update to version 4.19.9:
  * fix monitor thread termination and update tests
- Add support_pandas_23_groupby.patch
  * Fix for pandas 0.23.0 support
  * See: https://github.com/tqdm/tqdm/pull/554
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.8:
  * TqdmMonitorWarning
  * warnings.warn
  * log.info
  * abstract and no-raise monitor error
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.7:
  * fix: Avoid manipulating uninitialized instances on monitoring
    thread.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.19.6:
  * CLI improvements
    + --bytes implies --unit B --unit_scale --unit_divisor 1024 (#503)
    + allow hyphens in CLI arguments (#511)
  * synchronisation: fix for sem_open on aarch64 (#513)
  * framework update
    + CI/tests, year 2018, py37, badges, documentation
* Sun Dec 10 2017 arun@gmx.de
- update to version 4.19.5:
  * multiprocess/lock fixes (#457)
  * set_description in notebook (#345 -> #475)
  * minor tidy (#476)
  * documentation updates
* Sun Oct 15 2017 arun@gmx.de
- update to version 4.19.4:
  * fix Lock:NotImplementedError on certain systems (#466 -> #468)
  * use recursive locks (#469 -> #468)
    + fix deadlocks
  * tidy (#448)
  * flush() on moveto() (#398 -> #399, #420, #467)
  * update tests and benchmarks
- changes from version 4.19.3:
  * no changelog available
* Tue Oct 10 2017 arun@gmx.de
- specfile:
  * added man page, fixed path for man-page in setup.py
  * added fdupes
- update to version 4.19.2:
  * flush() on refresh() (#459 from #317)
  * status printer updates (#331)
    + use sp() in refresh()
    + remove redundant clear():nomove=False
  * misc minor documentation updates
  * unit tests
- changes from version 4.19.1:
  * rate_(no)inv(_fmt) (#72, b228bc3)
  * __repr__() tidy (#389)
  * fix write() before initialisation AttributeError: _lock (#457)
  * man pages
  * documentation updates
* Fri Oct  6 2017 jengelh@inai.de
- Redo description with sensible content.
* Tue Oct  3 2017 arun@gmx.de
- update to version 4.18.0:
  * Thread safety! (#285 -> #291 -> #329, #407, #417)
  * Ease redirection of sys.stdout/stderr (#422)
  * Minor internal stream bugfix (#439)
  * AttributeError fixes (#323, #324, #418)
  * Related to:
    + Misc bugs (#334)
    + concurrent.futures (#97)
    + Multi-tqdm (#143)
    + flush() and refresh() (#331)
    + Newline on refresh() (#361)
    + Nested trees (#384)
    + Manually positioned nested bars clearing (#385)
* Sun Sep 24 2017 arun@gmx.de
- update to version 4.17.1:
  * __repr__() bugfix
  * better unicode detection
  * initialise `n` even when disabled
- changes from version 4.17.0:
  * easier redirect of stdout (#426 -> #431)
    + cls.external_write_mode() @contextmanager
  * refresh=True for set_description/update(_str) (#317 -> #377)
- changes from version 4.16.0:
  * more formatting control (#347 -> #362)
    + set_postfix_str(), set_description_str()
    + move ": " to bar_format
    + complements #266, #270
  * better CLI support (e.g. hyphenated paths) (#421 #423 -> #424)
  * more unit tests (#411)
    + upgrade to pypy2/3-5.8.0
    + add py37-dev
  * doc updates
- changes from version 4.15.0 :
  * minor fixes (#395)
  * minor documentation updates (#400, #401, #412)
  * better pandas support (#351 -> #409)
  * Jupyter notebook fix (#352, #369 -> #373, #405)
  * optimise setcheckinterval/setswitchinterval (#376)
  * add unit_scale (#273, #295 -> #378)
* Wed Jul  5 2017 sebix+novell.com@sebix.at
- upgrade specfile to singlespec
- upgrade to 4.14.0
* Wed Mar  1 2017 toddrme2178@gmail.com
- Update to 4.11.2
  * thread safety #332
  * address DeprecationWarning #319 -> #326
  * version extra #328 -> #330
    + security fix
    + add non-master branch name
    + Fixes BNC#1017485
    + Fixes CVE#CVE-2016-10075
  * minor safety
  * minor documentation and comments
- Update to 4.11.1
  * Officially support Python 3.6, addressing #333
- Update to 4.11.0
  * postfix argument added #266->#270
  * fix tests for
    + numpy #272->#302
    + PyPy3 #318->#325
  * 7z extraction example script
  * new logo #315
  * hit counter with logo colours and stats
  * documentation updates
  * safer setup.py Makefile emulation
  * better github contributions integrations and Code of Conduct #310
- update to version 4.10.0:
  * fix maxinterval to adjust miniters to mininterval #249
  * minor bugfixes (eg #288)
  * misc optimisations, unit tests, and benchmarks (eg #298)
  * documentation updates
- update to version 4.9.0:
  * monitoring thread to automatically to adjust miniters and avoid
    exceeding maxinterval
    + test race conditions
    + kill on KeyboardInterrupt + instant refresh
    + low performance overhead, option to disable
  * new CLI argument: --bytes to count chars
  * disable automatically on non-TTY (#281)
  * fixed refresh() and clear() if disabled (#286)
  * misc fixes
  * documentation
  * unit tests
  * optimisations, style fixes
  * codacy badge
  * safety and warning suppression
  * ignore coverall failures (#283)
  * fix broken link in README (#262)
  * Fix time() in refresh() + avoid write() races (#264)
  * Fix __repr__() #269
  * Fix update(0) causing ZeroDivisionError (on first call) #268
  * Faster simple bar for perf test (#257)
  * cleaner tqdm_notebook exit when not run in a notebook (#267)
  * Disable coveralls because of duplicate comments on github (#263)
  * Migrate codecov config -> codecov.yml
* Mon Sep 19 2016 toddrme2178@gmail.com
- update to version 4.8.4:
  * 14%% overhead reduction
  * fix exception when closing tqdm_notebook without a total
  * support more pandas modules
  * pandas.Series.progress_map
  * pandas.DataFrame.progress_applymap
  * Panel.progress_apply
  * PanelGroupBy.progress_apply
  * GroupBy.progress_aggregate
  * GroupBy.progress_transform
  * faster CI builds
  * misc documentation update and link to wiki
- update to version 4.8.3:
  (no changelog available)
- update to version 4.8.2:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.1:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.0:
  * tqdm.pandas classmethod replaces tqdm_pandas function (deprecated)
  * ipython aliased imports fixes
  * write without any instances
  * readme update
  * examples update
  * test fixes and updates
- update to version 4.7.6:
  * numpy len support, addressing #185
- update to version 4.7.5:
  * spring clean (mostly pragma)
  * addresses #182
  * series len, tests
  * disable support (fixes #184), fkake8 fixes
- update to version 4.7.4:
  * pandas.DataFrame.apply support
  * tqdm_notebook.write()
  * tqdm_gui.write()
  * misc notebook fixes
  * delay notebook imports (>80%% reduction in import time when unused)
  * optional colorama only on windows
  * documentation tidy
  * more & faster tests
- update to version 4.7.1:
  * pandas.DataFrame.apply support
- update to version 4.7.0:
  * CLI custom delimiter support
  * More robust CLI argument parsing
  * either one or two - preceding kwargs (eg -ascii or --ascii)
  * no positional args (so no need to quote multi-word -desc for
    example)
  * bool kwargs with implicit value=True still supported
  * optional = sign after kwargs
  * tests
  * doc updates, badges
  * pyversions, doi, licence, github
- update to version 4.6.2:
  * Fix warnings due to IPython/Jupyter widget
- update to version 4.6.1:
  * add IPython/Jupyter support
  * fix {bar} length breaking display when using custom bar_format
  * add a no inversion rate formatting for bar_format (i.e., always
    show it/s and never s/it)
- update to version 4.6.0:
  * (no changelog availabel)
- update to version 4.5.0:
  * print messages within (nested) loops using tqdm.write(...)
- update to version 4.4.3:
  * remove docopt dependency for CLI
  * re-added update(0) ability to trigger refresh
  * minor fixes
  * re-added (OSI approved) licence to source
  * dev versioning auto-fallback
  * slight speed optimisation
  * tests
  * documentation
- update to version 4.4.2:
  * no changelog available
- update to version 4.4.1:
  * remove "dumb binaries" from build, coverage
- update to version 4.4.0:
  * modularise
- update to version 4.3.0:
  * fix_position
  * tidy
- update to version 4.2.0:
  * licencizors
- update to version 4.1.0:
  * compat-fixes
- update to version 4.0.0:
  * automate nested
    + deprecate nested
    + add manual override control with position
  * documentation and example updates, coverage and tests
  * make leave==True by default (was False)
* Mon Feb  1 2016 arun@gmx.de
- update to version 3.8.0:
  * update(n<1) raises error
  * sanitise and update examples and README
  * fix setup.py encoding error
  * remove py32 from Travis
  * changelog more accessible from README
* Wed Jan 20 2016 toddrme2178@gmail.com
- Initial version
